==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/InstanceMetricName.scala <==
package zio.aws.lightsail.model
import scala.jdk.CollectionConverters._
sealed trait InstanceMetricName {
  def unwrap: software.amazon.awssdk.services.lightsail.model.InstanceMetricName
}
object InstanceMetricName {
  def wrap(
      value: software.amazon.awssdk.services.lightsail.model.InstanceMetricName
  ): zio.aws.lightsail.model.InstanceMetricName = value match {
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.CPU_UTILIZATION =>
      val r = CPUUtilization
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_IN =>
      val r = NetworkIn
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_OUT =>
      val r = NetworkOut
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED =>
      val r = StatusCheckFailed
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_INSTANCE =>
      val r = StatusCheckFailed_Instance
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_SYSTEM =>
      val r = StatusCheckFailed_System
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_TIME =>
      val r = BurstCapacityTime
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_PERCENTAGE =>
      val r = BurstCapacityPercentage
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.UNKNOWN_TO_SDK_VERSION
  }
  case object CPUUtilization
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.CPU_UTILIZATION
  }
  case object NetworkIn extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_IN
  }
  case object NetworkOut extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_OUT
  }
  case object StatusCheckFailed
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED
  }
  case object StatusCheckFailed_Instance
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_INSTANCE
  }
  case object StatusCheckFailed_System
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_SYSTEM
  }
  case object BurstCapacityTime
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_TIME
  }
  case object BurstCapacityPercentage
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_PERCENTAGE
  }
}

==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/InstanceMetricName.scala <==
package zio.aws.lightsail.model
import scala.jdk.CollectionConverters._
sealed trait InstanceMetricName {
  def unwrap: software.amazon.awssdk.services.lightsail.model.InstanceMetricName
}
object InstanceMetricName {
  def wrap(
      value: software.amazon.awssdk.services.lightsail.model.InstanceMetricName
  ): zio.aws.lightsail.model.InstanceMetricName = value match {
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.CPU_UTILIZATION =>
      val r = CPUUtilization
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_IN =>
      val r = NetworkIn
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_OUT =>
      val r = NetworkOut
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED =>
      val r = StatusCheckFailed
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_INSTANCE =>
      val r = StatusCheckFailed_Instance
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_SYSTEM =>
      val r = StatusCheckFailed_System
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_TIME =>
      val r = BurstCapacityTime
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_PERCENTAGE =>
      val r = BurstCapacityPercentage
      r
    case software.amazon.awssdk.services.lightsail.model.InstanceMetricName.METADATA_NO_TOKEN =>
      val r = MetadataNoToken
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.UNKNOWN_TO_SDK_VERSION
  }
  case object CPUUtilization
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.CPU_UTILIZATION
  }
  case object NetworkIn extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_IN
  }
  case object NetworkOut extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.NETWORK_OUT
  }
  case object StatusCheckFailed
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED
  }
  case object StatusCheckFailed_Instance
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_INSTANCE
  }
  case object StatusCheckFailed_System
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.STATUS_CHECK_FAILED_SYSTEM
  }
  case object BurstCapacityTime
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_TIME
  }
  case object BurstCapacityPercentage
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.BURST_CAPACITY_PERCENTAGE
  }
  case object MetadataNoToken
      extends zio.aws.lightsail.model.InstanceMetricName {
    override def unwrap
        : software.amazon.awssdk.services.lightsail.model.InstanceMetricName =
      software.amazon.awssdk.services.lightsail.model.InstanceMetricName.METADATA_NO_TOKEN
  }
}
